@@ -41,4 +41,10 @@ class CreateProjectRequest(RpcRequest):
 		return self.get_body_params().get('Name')
 
 	def set_Name(self,Name):
-		self.add_body_params('Name', Name)
\ No newline at end of file
+		self.add_body_params('Name', Name)
+
+	def get_AggregateSceneCode(self):
+		return self.get_body_params().get('AggregateSceneCode')
+
+	def set_AggregateSceneCode(self,AggregateSceneCode):
+		self.add_body_params('AggregateSceneCode', AggregateSceneCode)
\ No newline at end of file
